# SciTeX CSV Formatters (Preserved)

These 65+ files implement SigmaPlot-compatible CSV export for each matplotlib/seaborn plot type.
Originally from scitex.plt._subplots._export_as_csv_formatters.
Deferred from Phase 2 of the scitex->figrecipe migration.
Not part of figrecipe's public API.
